@@ -13,6 +13,7 @@
 #include <kdockwidget.h>
 
 #include "kitaview.h"
+#include "kitaconfig.h"
 
 class KPrinter;
 class KToggleAction;
@@ -20,6 +21,7 @@ class KURL;
 class KitaThreadView;
 class KitaBoardView;
 class KitaSubjectView;
+class KLineEdit;
 
 namespace KParts{
   class URLArgs;
@@ -33,6 +35,7 @@ namespace KParts{
  * @author $AUTHOR <$EMAIL>
  * @version $APP_VERSION
  */
+
 class Kita : public KDockMainWindow
 {
     Q_OBJECT
@@ -72,6 +75,9 @@ protected:
      */
     void readProperties(KConfig *);
 
+    void readConfig(KConfig *);
+    void writeConfig(KConfig *);
+
 private slots:
     void fileNew();
     void fileOpen();
@@ -89,11 +95,16 @@ private slots:
     void changeCaption(const QString& text);
     void slotOpenURLRequest(const KURL& url, const KParts::URLArgs&);
     void slotSetVestedNum(const KURL& threadURL, int resCount);
+    void slotFontChanged(QFont& font);
+    void slotWriteSucceeded();
+    void slotUrlLine();
+    void setUrl(const KURL& url);
 
 private:
     KitaThreadView *m_threadView;
     KitaBoardView* m_boardView;
     KitaSubjectView* m_subjectView;
+    KLineEdit* m_urlLine;
 
     KPrinter   *m_printer;
     KToggleAction *m_toolbarAction;
