@@ -37,7 +37,7 @@ enum SubjectViewRows {
   Row_ResNum,
   Row_Vested,
   Row_Unread,
-  Row_DatName,
+  Row_DatName
 };
 
 KitaSubjectView::KitaSubjectView(QWidget *parent, const char *name)
@@ -94,15 +94,15 @@ void KitaSubjectView::slotLoadBoard(const KURL& url, const QString& boardName)
   m_board = Kita2ch::Board(url, boardName);
   m_board.refreshChildList();
 
-  KitaCacheInfo* cache = KitaCacheInfo::getInstance();  
+  KitaCacheInfo* cache = KitaCacheInfo::getInstance();
   QPtrList<Kita2ch::Thread> threadList = m_board.getThreadList();
-  
+
   // clear list
   subjectList->clear();
-  
-  for(int i=0; i<threadList.count(); i++) {
+
+  for(unsigned i=0; i<threadList.count(); i++) {
     Kita2ch::Thread* thread = threadList.at(i);
-    
+
     int vested = cache->getVestedNum(thread->datURL());
     new KListViewItem(subjectList,
                       QString("%1").arg(i+1, 4),
@@ -110,13 +110,14 @@ void KitaSubjectView::slotLoadBoard(const KURL& url, const QString& boardName)
                       thread->name(),
                       QString("%1").arg(thread->resNum(), 4),
                       vested > 0 ? QString::number(vested) : "",
-                      vested > 0 ? QString::number(thread->resNum() - vested) : "",
+                      vested > 0 && thread->resNum() != vested ? QString::number(thread->resNum() - vested) : "",
                       thread->datURL().fileName());
   }
 
   if( HideButton->isOn() ) {
     HideButton->toggle();
   }
+  emit loadBoardCompleted(m_board.url());
 }
 
 void KitaSubjectView::slotSearchButton()
@@ -211,4 +212,5 @@ void KitaSubjectView::slotHideButton(bool on)
 
 void KitaSubjectView::slotFontChanged(QFont& font)
 {
+  subjectList->setFont(font);
 }
