@@ -41,7 +41,7 @@ public slots:
 private: // Private attributes
   Kita2ch::Board m_board;
   QStringList m_prevquery;
-  int m_nextHitIndex;
+  unsigned m_nextHitIndex;
   QValueList<KListViewItem*> m_hitList;
   
   void insertSearchCombo();
@@ -53,6 +53,7 @@ private slots:
   void slotSearchButton();
 
 signals:
+  void loadBoardCompleted(const KURL&);
   void signalShowThread(const Kita2ch::Board& board, const Kita2ch::Thread& thread);
   void signalSubjectListClicked(QListViewItem* item);
 };
