@@ -1,4 +1,4 @@
-/***************************************************************************
+/**************************************************************************
  *   Copyright (C) 2003 by Hideki Ikemoto                                  *
  *   ikemo@wakaba.jp                                                       *
  *   linux 󥫥פ餰ο                                        *
@@ -9,9 +9,7 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#include <qfile.h>
 #include <qtextstream.h>
-#include <qtextcodec.h>
 #include <qlayout.h>
 #include <qtoolbutton.h>
 #include "qcp932codec.h"
@@ -19,17 +17,14 @@
 #include <qlabel.h>
 #include <qcombobox.h>
 #include <qprogressdialog.h>
-#include <qvaluestack.h>
 
 #include <time.h>
 
 #include <kurl.h>
-#include <kio/netaccess.h>
 #include <kio/slaveconfig.h>
 #include <kio/jobclasses.h>
 #include <kio/scheduler.h>
 
-#include <khtml_part.h>
 #include <khtmlview.h>
 #include <dom/html_element.h>
 #include <dom/html_inline.h>
@@ -40,7 +35,9 @@
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kaction.h>
+#include <kmessagebox.h>
 
+#include "kitahtmlpart.h"
 #include "kitathreadview.h"
 #include "kitawritedialog.h"
 #include "../kitacacheinfo.h"
@@ -48,19 +45,27 @@
 
 #include <qmessagebox.h>
 
+static const char* cookie_title = "񤭹߳ǧ";
+static const char* cookie_message =
+"Ƴǧ\n"
+"Ƥ줿Ƥϥԡ¸ѡž礬ޤ\n"
+"Ƥ˴ؤȯǤƼԤ˵ޤ\n"
+"\n"
+"Ǥ餦Ȥƽ񤭹ߤޤ\n";
+
 KitaThreadView::KitaThreadView(QWidget *parent, const char *name)
     : KitaThreadViewBase(parent, name)
     , m_parent( parent )
     , m_currentJob( 0 )
     , m_labelMaxLength( 60 )
 {
-  m_threadPart = new KHTMLPart(threadFrame);
+  m_threadPart = new KitaHTMLPart(threadFrame);
   QHBoxLayout* aLayout = new QHBoxLayout(threadFrame);
   aLayout->addWidget(m_threadPart->view());
 
   {
     m_threadPart->setStandardFont("Gothic [Mona]");
-    m_threadPart->setZoomFactor(120); // 12px;    
+    m_threadPart->setZoomFactor(120); // 12px;
 #if 0 // provides you with mona font info.
     QString info;
     info +=  view()->font().family();
@@ -69,7 +74,7 @@ KitaThreadView::KitaThreadView(QWidget *parent, const char *name)
     QMessageBox::information( 0, "", info );
 #endif
   }
-  
+
   {
     SearchButton->setPixmap( SmallIcon("find") );
     HighLightButton->setPixmap( SmallIcon("idea") );
@@ -86,6 +91,8 @@ KitaThreadView::KitaThreadView(QWidget *parent, const char *name)
   connect( writeButton, SIGNAL(clicked()), SLOT(slotWriteButtonClicked()));
   connect( m_threadPart, SIGNAL( nodeActivated(const DOM::Node &) ), SLOT( slotDOMNodeActivated(const DOM::Node &) ) );
   connect( m_threadPart, SIGNAL( onURL(const QString&) ), SLOT( slotOnURL(const QString&) ) );
+  connect( m_threadPart, SIGNAL( setLocationBarURL(const QString &) ),
+  			 SIGNAL( setLocationBarURL(const QString &) ) );
   connect( SearchButton, SIGNAL( clicked() ), SLOT( slotSearchButton() ) );
   connect( SearchCombo, SIGNAL( activated(int) ), SLOT( slotSearchButton() ) );
   connect( HighLightButton, SIGNAL( toggled(bool) ), SLOT( slotHighLightenButton(bool) ) );
@@ -124,29 +131,28 @@ void KitaThreadView::slotDOMNodeActivated(const DOM::Node &node)
     {
       printf("  AnchorNodeActivated:: \n" );
     } // end: anchor.href().isEmpty()
-  } // end of Anchor tags. 
+  } // end of Anchor tags.
 }
 
-//void KitaThreadView::slotShowThread(const KURL& _datURL, const KURL& _boardURL, const QString& boardName)
 void KitaThreadView::slotShowThread(const Kita2ch::Board& board, const Kita2ch::Thread& thread)
 {
   { //reset member variables associated with a thread.
-    m_prevquery = "";
-    m_nextHit = 0;
-    m_hitcount = 0;
+    m_threadPart->setPrevQuery("");
+    m_threadPart->resetHit();
+    m_threadPart->resetHitCount();
     m_writeResult = "";
     m_threadData = "";
-    m_contents = "";
-    m_pointStack.clear();
+    m_threadPart->setContents("");
+    m_threadPart->clearPosition();
   }
 
   m_board = board;
   m_thread = thread;
-  if ( m_thread.datURL().protocol() != "k2ch" ) { 
+  if ( m_thread.datURL().protocol() != "k2ch" ) {
     KIO::SlaveConfig::self()->setConfigData("http", m_thread.datURL().host() ,
-                                          "UserAgent", "Monazilla/1.00 (Kita/0.3)");
+                                          "UserAgent", "Monazilla/1.00 (Kita/0.4)");
   }
-    
+
   KIO::TransferJob* job = KIO::get(m_thread.datURL(), true, true);
   m_currentJob = job;
 
@@ -192,6 +198,19 @@ int KitaThreadView::getServerTimeFromHttpHeaders(QString headers)
   }
 }
 
+void KitaThreadView::setSubjectLabel(const QString& boardName, const QString& threadName)
+{
+  QString disp;
+  if ( boardName.isEmpty() ) {
+    disp = threadName;
+  } else {
+    disp = QString("[%1] %2").arg(boardName).arg(threadName);
+  }
+
+  disp.truncate( m_labelMaxLength );
+  subjectLabel->setText( disp );
+}
+
 void KitaThreadView::slotThreadResult(KIO::Job* job)
 {
   m_currentJob = 0;
@@ -217,11 +236,11 @@ void KitaThreadView::slotThreadResult(KIO::Job* job)
   progress->setTotalSteps( static_cast<int>(total * 0.7) );
   progress->setLabelText( "Parse DAT file.....");
   progress->show();
-  
+
   text += "<html><head>";
   text += "</head><body>";
   while(!stream.atEnd()) {
-    
+
     line = stream.readLine();
     Kita2ch::Comment comment(line);
     if( comment.isValid() == false) {
@@ -240,15 +259,19 @@ void KitaThreadView::slotThreadResult(KIO::Job* job)
     }
   }
   delete progress;
-  
+
   m_thread.setResNum(num);
   emit setVestedNum(m_thread.datURL(), m_thread.resNum());
 
+#if 0
   QString disp( m_thread.name() );
   if ( ! m_board.name().isEmpty() ) { disp.prepend( QString("[%1]").arg(m_board.name()) ); }
   disp.truncate( m_labelMaxLength );
   subjectLabel->setText( disp );
-  
+#else
+  setSubjectLabel( m_board.name(), m_thread.name() );
+#endif
+
   {
     int target;
     for ( target = 1; target < m_thread.resNum(); target += 100 )
@@ -259,9 +282,9 @@ void KitaThreadView::slotThreadResult(KIO::Job* job)
   text += QString("<a href=\"%1#%2\">check new one.</a>").arg( m_datURL.url() ).arg( m_rescount );
 #endif
   text += "</body></html>";
-  m_contents = text;
+  m_threadPart->setContents(text);
 
-  slotDisplayContents( m_contents, m_thread.datURL() );
+  slotDisplayContents( m_threadPart->contents(), m_thread.datURL() );
   if ( HighLightButton->isOn() ) {
     HighLightButton->toggle();
   }
@@ -273,62 +296,87 @@ void KitaThreadView::slotThreadResult(KIO::Job* job)
   } else {
     gotoAnchor( QString().setNum(m_thread.resNum() - 1) );
   }
-  m_pointStack.clear();
-  KHTMLView * view = m_threadPart->view();
-  m_pointStack.push( QPoint( view->contentsX(), view->contentsY() ) );
+  m_threadPart->clearPosition();
+  m_threadPart->pushCurrentPosition();
 
-  emit showThreadCompleted();
+  emit showThreadCompleted( m_thread.url() );
+}
+
+void KitaThreadView::slotShowErrorDialog(const QString& input, const KURL&)
+{
+  qDebug("#%s#", (const char *)input.local8Bit());
+  Kita2ch::WriteResult writeResult(input);
+
+  qDebug("code = %d", writeResult.code());
+  switch( writeResult.code() ) {
+  case Kita2ch::K2ch_Unknown:
+    // probably OK.
+    emit writeSucceeded();
+    slotReloadButton();
+    break;
+  case Kita2ch::K2ch_True:
+    KMessageBox::error(0, writeResult.message(), writeResult.title());
+    break;
+  case Kita2ch::K2ch_False:
+    KMessageBox::error(0, writeResult.message(), writeResult.title());
+    break;
+  case Kita2ch::K2ch_Error:
+    KMessageBox::error(0, writeResult.message(), writeResult.title());
+    break;
+  case Kita2ch::K2ch_Check:
+    KMessageBox::error(0, writeResult.message(), writeResult.title());
+    break;
+  case Kita2ch::K2ch_Cookie:
+    if( KMessageBox::questionYesNo(0, QString::fromLocal8Bit(cookie_message),
+                                      QString::fromLocal8Bit(cookie_title)) == KMessageBox::Yes) {
+      KitaWriteDialog* dialog = openDialog( m_postInfo );
+      dialog->postMessage();
+    } else {
+      KitaWriteDialog* dialog = openDialog( m_postInfo );
+      dialog->show();
+    }
+    break;
+  default:
+    break;
+  }
 }
 
 void KitaThreadView::slotDisplayContents(const QString& input, const KURL& url)
 {
-  printf("    begin Display: %s\n", url.url().latin1() );
-  m_threadPart->begin( url );
-  m_threadPart->write( input );
-  m_threadPart->end();
-  if ( ! url.isEmpty() ) emit setLocationBarURL(url.url());
+  m_threadPart->slotDisplayContents(input, url);
+}
+
+KitaWriteDialog* KitaThreadView::openDialog(Kita2ch::PostInfo& info)
+{
+  KitaWriteDialog* new_dialog = KitaWriteDialog::open( info );
+  connect( new_dialog, SIGNAL( postStarted( KIO::Job *, const Kita2ch::PostInfo& ) ),
+           this, SLOT( slotPostStarted( KIO::Job*, const Kita2ch::PostInfo&) ) );
+  connect( new_dialog, SIGNAL( postResponse(const QString&, const KURL&) ),
+      	   this, SLOT( slotShowErrorDialog(const QString&, const KURL&) ) );
+#if 0 // !!postRenponce!!
+  connect( new_dialog, SIGNAL( postResponse(const QString&, const KURL&) ),
+      	   this, SLOT( slotDisplayContents(const QString&, const KURL&) ) );
+#else
+  connect( new_dialog, SIGNAL( postResponse(const QString&, const KURL&) ),
+      	   this, SIGNAL( postResponse(const QString&, const KURL&) ) );
+#endif
+  return new_dialog;
 }
 
 void KitaThreadView::slotWriteButtonClicked()
 {
-  KitaWriteDialog dialog;
-
   QSjisCodec cp932Codec;
   KURL bbscgiURL = KURL(m_board.url(), "../test/bbs.cgi");
   bbscgiURL.setProtocol( "http" );
 
-  KitaWriteDialog::PostInfo info;
+  Kita2ch::PostInfo info;
   info.host = bbscgiURL.host();
   info.bbs = m_board.id();
   info.key = m_thread.datID();
   info.time = QString("%1").arg(m_serverTime);
-  QDialog * new_dialog = KitaWriteDialog::open( info );
-  connect( new_dialog, SIGNAL( postResponse(const QString&, const KURL&) ),
-      	   this, SLOT( slotDisplayContents(const QString&, const KURL&) ) );
-  new_dialog->show(); //work asynchronus.
-}
 
-void KitaThreadView::slotReceiveWriteResult(KIO::Job *,  const QByteArray & data)
-{
-  QCString cstr(data.data(), data.size()+1);
-  m_writeResult += cstr;
-}
-
-void KitaThreadView::slotWriteResult(KIO::Job* job)
-{
-  if(job->error()) {
-    job->showErrorDialog();
-  } else {
-    QSjisCodec codec;
-    QTextStream stream(m_writeResult, IO_ReadOnly);
-    stream.setCodec(&codec);
-
-    m_threadPart->begin();
-    m_threadPart->write( m_writeResult.data(), m_writeResult.size() );
-    m_threadPart->end();
-    qDebug("#%s#", (const char *)stream.read().local8Bit());
-    m_writeResult.truncate(0);
-  }
+  KitaWriteDialog* dialog = openDialog( info );
+  dialog->show(); // work asynchronus.
 }
 
 void KitaThreadView::slotCanceled(KIO::Job*)
@@ -379,19 +427,17 @@ void KitaThreadView::searchNext(const QStringList &query)
   if ( query.isEmpty() ) return;
   if ( ! HighLightButton->isOn() ) {
     HighLightButton->toggle();
-    m_nextHit = 0; //A next jump-search target reset to '0'.
+    m_threadPart->resetHit(); //A next jump-search target reset to '0'.
     // Process works asynchronusly. So Firstly, we don't do jump-search as a simple solution.
     return;
   }
-  if ( query != m_prevquery ) {
+  if ( query != m_threadPart->prevQuery() ) {
     highLighten( true, query );
-    m_nextHit = 0; //A next jump-search target reset to '0'.
+    m_threadPart->resetHit(); //A next jump-search target reset to '0'.
     return;
   }
-    
-  gotoAnchor( QString("highlighten%1").arg(m_nextHit)  );
-  ++m_nextHit;
-  if ( !( m_nextHit < m_hitcount ) ) m_nextHit = 0;
+
+  gotoAnchor( QString("highlighten%1").arg( m_threadPart->nextHit() )  );
 }
 
 void KitaThreadView::highLighten(bool yes, const QStringList &query)
@@ -409,90 +455,17 @@ void KitaThreadView::highLighten(bool yes, const QStringList &query)
 #else
   highlightCSS = highlightCSS.arg( "yellow" ).arg( "black" );
 #endif
-  m_threadPart->setUserStyleSheet( highlightCSS );
-  
-
-  if ( m_prevquery == query ) return;
-  m_prevquery = query;
-  if ( query.isEmpty() ) return;
-
-  slotDisplayContents( m_contents, m_thread.datURL() );
-  DOM::NodeList nodes;
-  m_hitcount = 0;
-  nodes = m_threadPart->document().getElementsByTagName("body");
-  highLightenNodes( nodes, query );
-  m_threadPart->setUserStyleSheet( highlightCSS );
-}
-
-QStringList KitaThreadView::lt_gt_spliter( const QString & input )
-{
-  QStringList lt_gt_splitted;
-  QRegExp lt_gt("[<>]");
-  int start = 0;
-  int end = 0;
-  while ( (end = input.find(lt_gt, end+1)) != -1 ) {
-    if ( input.at(end) == '<' ) {
-      lt_gt_splitted += input.mid( start, end-start );
-      start = end;
-    } else
-    if ( input.at(end) == '>' ) {
-      lt_gt_splitted += input.mid( start, end+1-start );
-      start = end + 1;
-    } else QMessageBox::warning( 0, "", "KitaThreadView::lt_gt_spliter()\n !!Bug!! Not Match.\n Will you contact with authors?");
-  }
-  lt_gt_splitted += input.mid( start );
-  return lt_gt_splitted;
-}
-
-void KitaThreadView::highLightenNodes(DOM::NodeList nodes, const QStringList &query)
-{
-  for ( unsigned int count = 0; count < nodes.length(); ++count ) {
-    DOM::HTMLElement dd = nodes.item(count);
-    //printf(" dd %d: %s\n", count, dd.innerHTML().string().latin1() );
-    QStringList lt_gt_split = lt_gt_spliter( dd.innerHTML().string() );
-
-    QProgressDialog progress(m_parent);
-    progress.setLabelText("Searching...");
-    progress.setTotalSteps( lt_gt_split.size() );
-    progress.show();
-    int step = 0;
-    int divide = lt_gt_split.size() / ( 100 / 5 );
-    int next = divide;
-
-    //loop order not optimized. Need optim. that also needs any codes & members?
-    QStringList::iterator it_msg = lt_gt_split.begin();
-    for( ; it_msg != lt_gt_split.end(); ++it_msg ) 
-    {
-      QStringList::const_iterator it = query.begin(); 
-      for( ; it != query.end(); ++it )
-      {
-	int pos = 0;
-	QString message = *it_msg;
-	//printf("dd %d: %s\n", count, (*it_msg).latin1() );
-	if( message.at(0) == '<' ) continue;
-	while ( (pos = (*it_msg).find(*it, pos)) != -1 ) {
-	  //QMessageBox::information( 0, "Hit!",  QString( "pos: %1 (length: %2)\nhitcount: %4\nstring:\n%3").arg(pos).arg((*it).length()).arg(message).arg(m_hitcount) );
-	  QString replace = QString("<font class=\"highlight\" id=\"highlighten%2\">").arg( m_hitcount );
-	  replace += *it;
-	  replace += "</font>";
-	  message.replace(pos, (*it).length(), replace);
-	  //printf("dd %d: replaced:: %s\n", count, message.latin1() );
-	  pos += replace.length();
-	  lt_gt_split.insert( it_msg, message );
-	  it_msg = lt_gt_split.remove( it_msg );
-	  --it_msg;
-	  ++m_hitcount;
-	}
-      }
-      if( ++step > next ) {
-	progress.setProgress( step );
-	next += divide;
-      }
-    }
-
-    dd.setInnerHTML( lt_gt_split.join(" ") );
+//  m_threadPart->setUserStyleSheet( highlightCSS );
 
+  if ( m_threadPart->prevQuery() != query && !query.isEmpty() ) {
+    m_threadPart->setPrevQuery(query);
+    slotDisplayContents( m_threadPart->contents(), m_thread.datURL() );
+    DOM::NodeList nodes;
+    m_threadPart->resetHit();
+    nodes = m_threadPart->document().getElementsByTagName("body");
+    m_threadPart->highLightenNodes( nodes, query );
   }
+  m_threadPart->setUserStyleSheet( highlightCSS );
 }
 
 void KitaThreadView::slotOnURL(const QString& url)
@@ -502,17 +475,12 @@ void KitaThreadView::slotOnURL(const QString& url)
 
 bool KitaThreadView::gotoAnchor( const QString &name )
 {
-  KHTMLView * view = m_threadPart->view();
-  m_pointStack.push( QPoint( view->contentsX(), view->contentsY() ) );
   return m_threadPart->gotoAnchor( name );
 }
 
 bool KitaThreadView::gobackAnchor()
 {
-  QPoint p = m_pointStack.pop();
-  if ( m_pointStack.isEmpty() ) m_pointStack.push( p );
-  m_threadPart->view()->setContentsPos( p.x(), p.y()  );
-  return true;
+  return m_threadPart->gobackAnchor();
 }
 
 void KitaThreadView::slotPopupMenu( KXMLGUIClient *client, const QPoint &global, const KURL &url, const QString &mimeType, mode_t mode)
@@ -545,7 +513,7 @@ void KitaThreadView::slotReloadButton()
 {
   slotShowThread(m_board, m_thread);
 }
-    
+
 KURL KitaThreadView::filterReadCGI(const KURL& url)
 {
   KURL  newURL = url;
@@ -575,5 +543,11 @@ KURL KitaThreadView::filterReadCGI(const KURL& url)
 void KitaThreadView::slotFontChanged(QFont& font)
 {
   m_threadPart->setStandardFont(font.family());
+  subjectLabel->setFont(font);
 }
 // vim:sw=2:
+
+void KitaThreadView::slotPostStarted( KIO::Job*, const Kita2ch::PostInfo& info)
+{
+  m_postInfo = info;
+}
