@@ -22,7 +22,8 @@
 #include "kita2ch.h"
 
 class KURL;
-class KHTMLPart;
+class KitaHTMLPart;
+class KitaWriteDialog;
 
 #include <qvaluestack.h> // for gcc-2.9x
 template<class T> class QValueStack;
@@ -32,12 +33,9 @@ namespace KIO {
 };
 
 #include <dom/html_base.h>
-namespace DOM {
-  class HTMLBodyElement;
-};
 
 /**
- * 
+ *
  * Hideki Ikemoto
  **/
 
@@ -58,9 +56,8 @@ public slots:
   void slotRedirection(KIO::Job* job, const KURL &);
   void slotThreadResult(KIO::Job* job);
   void slotWriteButtonClicked();
-  void slotReceiveWriteResult(KIO::Job* job,  const QByteArray & data);
-  void slotWriteResult(KIO::Job* job);
   void slotCanceled(KIO::Job* job);
+  void slotShowErrorDialog(const QString& input, const KURL& urlOfInput = 0);
   void slotDisplayContents(const QString& input, const KURL& urlOfInput = 0);
   void slotShowThread(const Kita2ch::Board& board, const Kita2ch::Thread& thread);
   void slotFontChanged(QFont& font);
@@ -77,35 +74,33 @@ protected slots:
 private: // Private attributes
   Kita2ch::Board m_board;
   Kita2ch::Thread m_thread;
-  KHTMLPart* m_threadPart;
+  KitaHTMLPart* m_threadPart;
   QCString m_threadData;
   QCString m_writeResult;
   int m_serverTime;
   QWidget * m_parent;
   KIO::Job * m_currentJob;
-  QString m_contents;
-  QStringList m_prevquery;
   int m_labelMaxLength;
-  int m_hitcount;
-  int m_nextHit;
-  QValueStack<QPoint> m_pointStack;
-  
-  void highLightenNodes(DOM::NodeList nodes, const QStringList &query);
-  static QStringList lt_gt_spliter( const QString & input );
+  Kita2ch::PostInfo m_postInfo;
+
   void insertSearchCombo();
   KURL filterReadCGI(const KURL&);
   int getServerTimeFromHttpHeaders(QString headers);
+  void setSubjectLabel(const QString& boardName, const QString& threadName);
+  KitaWriteDialog* openDialog(Kita2ch::PostInfo& info);
 
 private slots:
   void slotSearchButton();
   void slotHighLightenButton(bool yes);
   void slotOnURL(const QString& url);
   void slotReloadButton();
+  void slotPostStarted( KIO::Job*, const Kita2ch::PostInfo&);
 
 signals:
-  void showThreadCompleted();
+  void showThreadCompleted(const KURL& threadUrl);
   void datURLRedirected(const KURL& newDatURL);
   void signalChangeStatusbar(const QString&);
+  void postResponse( const QString& response, const KURL& bbscgi = KURL() );
   //re-impl signals of KParts::Browserextension of KHTMLPart
   void openURLRequest( const KURL &url, const KParts::URLArgs &args = KParts::URLArgs() );
   void createNewWindow( const KURL &url, const KParts::URLArgs &args = KParts::URLArgs() );
@@ -113,7 +108,8 @@ signals:
   void enableAction( const char * name, bool enabled );
   void popupMenu(KXMLGUIClient *, const QPoint&, const KURL&, const QString&, mode_t);
   void setVestedNum(const KURL& , int );
-  
+  void writeSucceeded();
+
   friend class KitaThreadPart;
 };
 
