@@ -10,6 +10,7 @@
 
 #include "kitawritedialog.h"
 #include "qcp932codec.h"
+#include "kitaconfig.h"
 
 #include <qlineedit.h>
 #include <qtextedit.h>
@@ -24,9 +25,9 @@ KitaWriteDialog::KitaWriteDialog(QWidget *parent, const char *name)
   : KitaWriteDialogBase(parent, name)
 {
   //QFont font = font();
-  QFont font;
-  font.setFamily("Gothic [Mona]");
-  font.setPixelSize( 12 );
+  QFont font = KitaConfig::font();
+//  font.setFamily("Gothic [Mona]");
+//  font.setPixelSize( 12 );
   bodyText->setFont( font );
   nameLine->setFont( font );
   nameLabel->setFont( font );
@@ -53,16 +54,16 @@ QString KitaWriteDialog::body()
   return bodyText->text();
 }
 
-void KitaWriteDialog::fetchPostInfo( PostInfo * storage )
+void KitaWriteDialog::fetchPostInfo( Kita2ch::PostInfo * storage )
 {
   storage->name = name();
   storage->mail = mail();
   storage->body = body();
 }
 
-KitaWriteDialog *  KitaWriteDialog::open( const PostInfo& info )
+KitaWriteDialog *  KitaWriteDialog::open( const Kita2ch::PostInfo& info )
 {
-  if ( ! checkPostInfo( info ) ) return 0;
+  if ( ! info.check() ) return 0;
   if ( ! s_private ) {
     s_private = new KitaWriteDialogPrivate;
     if ( ! s_private ) return 0;
@@ -70,19 +71,24 @@ KitaWriteDialog *  KitaWriteDialog::open( const PostInfo& info )
 
   KitaWriteDialog * new_dlg = new KitaWriteDialog;
   if ( ! new_dlg ) return 0;
-  
+
   new_dlg->m_postInfo = info;
   s_private->m_heaplist.append( new_dlg );
-  
+
   new_dlg->connect( new_dlg->buttonOk, SIGNAL( clicked() ), new_dlg, SLOT( postMessage() ) );
 
+  // set fields
+  new_dlg->nameLine->setText(info.name);
+  new_dlg->mailLine->setText(info.mail);
+  new_dlg->bodyText->setText(info.body);
+
   return new_dlg;
 }
 
 void KitaWriteDialog::postMessage()
 {
   fetchPostInfo( &m_postInfo );
-  if ( ! checkPostInfo( m_postInfo ) )
+  if ( ! m_postInfo.check() )
 	return ;
 
   KURL bbscgi;
@@ -91,17 +97,7 @@ void KitaWriteDialog::postMessage()
   bbscgi.setPath( m_postInfo.bbscgi );
 
   //int mib = QTextCodec::codecForName("CP932")->mibEnum();
-  QCp932Codec codec;
-  int mib = codec.mibEnum();
-  QString postStr;
-  (postStr += "submit=") += m_postInfo.submit;
-  (postStr += "&subject=");
-  (postStr += "&FROM=") += KURL::encode_string(m_postInfo.name, mib);
-  (postStr += "&mail=") += KURL::encode_string(m_postInfo.mail, mib);
-  (postStr += "&MESSAGE=") += KURL::encode_string(m_postInfo.body, mib);
-  (postStr += "&bbs=") += m_postInfo.bbs;
-  (postStr += "&key=") += m_postInfo.key;
-  (postStr += "&time=") += m_postInfo.time;
+  QString postStr = m_postInfo.postStr();
 
   printf("query: %s\n", postStr.latin1());
   m_array.resize(0);
@@ -113,7 +109,7 @@ void KitaWriteDialog::postMessage()
   if ( ! m_postInfo.cookie.isEmpty() )
 	  job->addMetaData("cookie", m_postInfo.cookie.prepend("Cookie: "));
 
-  emit postStarted( job );
+  emit postStarted( job, m_postInfo );
 
   connect( job, SIGNAL( data(KIO::Job*, const QByteArray&) ),
 	   this, SLOT( slotRecieveData(KIO::Job *, const QByteArray &) ) );
@@ -121,15 +117,6 @@ void KitaWriteDialog::postMessage()
 	   this, SLOT( slotPostFinished(KIO::Job *) ) );
 }
 
-bool KitaWriteDialog::checkPostInfo( const PostInfo& info )
-{
-  if ( info.host.isEmpty() || info.bbscgi.isEmpty()
-     || info.bbs.isEmpty() || info.key.isEmpty() )
-	return false;
-
-  return true;
-}
-
 void KitaWriteDialog::slotRecieveData(KIO::Job *, const QByteArray &data)
 {
   m_array.append( data.data() );
