@@ -14,6 +14,7 @@
 #include <qwidget.h>
 #include <kio/job.h>
 #include "kitawritedialogbase.h"
+#include "kita2ch.h"
 
 template<class type> class QPtrList;
 class KitaWriteDialogPrivate;
@@ -27,23 +28,6 @@ class KitaWriteDialog : public KitaWriteDialogBase
 {
   Q_OBJECT
 public:
-  struct PostInfo {
-    PostInfo() {
-	 bbscgi = "/test/bbs.cgi";
-	 submit = "%91%53%90%d3%94%43%82%f0%95%89%82%a4%82%b1%82%c6%82%f0%8f%b3%91%f8%82%b5%82%c4%8f%91%82%ab%8d%9e%82%de";
-    };
-    QString host;
-    QString bbscgi;
-    QString name;
-    QString mail;
-    QString body;
-    QString bbs;
-    QString key;
-    QString time;
-    QString submit;
-    QString cookie;
-  };
-
   KitaWriteDialog(QWidget *parent=0, const char *name=0 );
   virtual ~KitaWriteDialog();
   QString name();
@@ -52,22 +36,21 @@ public:
 
   virtual bool error(){ return false; };
 
-  static KitaWriteDialog * open( const PostInfo& info );
-  static bool checkPostInfo( const PostInfo& info );
+  static KitaWriteDialog * open( const Kita2ch::PostInfo& info );
 
 public slots:
   void postMessage();
 
 signals:
-  void postStarted( KIO::Job * );
+  void postStarted( KIO::Job *, const Kita2ch::PostInfo& );
   void postFinished( KIO::Job * );
   void postResponse( const QString& response, const KURL& bbscgi = KURL() );
 
 protected:
-  PostInfo m_postInfo;
+  Kita2ch::PostInfo m_postInfo;
 
 private:
-  void fetchPostInfo( PostInfo * storage );
+  void fetchPostInfo( Kita2ch::PostInfo * storage );
 
   QCString m_array;
   bool m_error;
