@@ -12,6 +12,7 @@
 #include <qpushbutton.h>
 
 #include "kitafontprefbase.h"
+#include "kitaconfig.h"
 
 KitaPreferences::KitaPreferences()
     : KDialogBase(TreeList, i18n("Kita Preferences"),
@@ -26,22 +27,25 @@ KitaPreferences::KitaPreferences()
 
 //    frame = addPage(i18n("Second Page"), i18n("Page Two Options"));
 //    m_pageTwo = new KitaPrefPageTwo(frame);
-    
+
     connect(m_fontPage, SIGNAL(signalFontChanged(QFont&)), SIGNAL(signalFontChanged(QFont&)));
 }
 
 KitaFontPrefPage::KitaFontPrefPage(QWidget *parent)
     : KitaFontPrefBase(parent)
 {
+  fontButton->setText(KitaConfig::font().family());
+  fontButton->setFont(KitaConfig::font());
   connect(fontButton, SIGNAL(clicked()), SLOT(slotFontButtonClicked()));
 }
 
 void KitaFontPrefPage::slotFontButtonClicked()
 {
-  QFont font;
+  QFont font = fontButton->font();
 
   if( KFontDialog::getFont(font, false, this) == QDialog::Accepted ) {
     fontButton->setText(font.family());
+    fontButton->setFont(font);
     emit signalFontChanged(font);
   }
 }
